pecos.qeclib
============

.. automodule:: pecos.qeclib



















.. rubric:: Modules

.. autosummary::
   :toctree:
   :recursive:

   pecos.qeclib.generic
   pecos.qeclib.qubit
   pecos.qeclib.steane
